@@ -88,6 +88,7 @@ class KameleoonClient:
         self.config = config(config_yml)
         self.logger = logger or get_logger()
         self.automation_base_url = "https://api.kameleoon.com/"
+        self.api_data_url = "https://api-data.kameleoon.com/"
         try:
             target_environment = self.config['target_environment']
         except KeyError:
@@ -744,6 +745,35 @@ class KameleoonClient:
         else:
             raise TypeError("Unknown type for feature variable")
 
+    def retrieve_data_from_remote_source(self,
+                                         key: str,
+                                         timeout: Optional[int] = DEFAULT_TIMEOUT_MILLISECONDS) -> Optional[Any]:
+        """
+        The retrieved_data_from_remote_source method allows you to retrieve data (according to a key passed as
+        argument)stored on a remote Kameleoon server. Usually data will be stored on our remote servers
+        via the use of our Data API. This method, along with the availability of our highly scalable servers
+        for this purpose, provides a convenient way to quickly store massive amounts of data that
+        can be later retrieved for each of your visitors / users.
+
+        :param key: key you want to retrieve data. This field is mandatory.
+        :type key: str
+        :param timeout: requests timeout (default value is 2000 milliseconds)
+        :type timeout: int
+
+        :return: data assosiated with this key, decoded into json
+        :rtype: Optional[Any]
+
+        :raises:
+
+            RequestException: All new network exceptions (timeout / connection refused and etc)
+            JSONDecodeError: Exceptions happen during JSON decoding
+        """
+        return self.make_sync_request(
+            url=self._get_api_data_request_url(key),
+            method='get',
+            headers=self._get_header_client(),
+            timeout=timeout)
+
     def _fetch_configuration(self) -> None:
         """
         :return:
@@ -797,17 +827,21 @@ class KameleoonClient:
             # self._fetch()
             time.sleep(actions_configuration_refresh_interval)
 
+    def _get_header_client(self) -> Dict[str, str]:
+        return {
+            'Kameleoon-Client': f'sdk/python/{kameleoon_python_version}'
+        }
+
     def _get_headers(self) -> Dict[str, str]:
         """
         :return: request headers with Authorization Bearer token
         """
         if not self.access_token:
             raise CredentialsNotFoundException
-        return {
+        return {**{
             'Authorization': f'Bearer {self.access_token}',
-            'Content-Type': 'application/json',
-            'Kameleoon-Client': f'sdk/python/{kameleoon_python_version}'
-        }
+            'Content-Type': 'application/json'
+        }, **self._get_header_client()}
 
     def _get_filter(self, field: str,
                     operator: str,
@@ -1027,6 +1061,18 @@ class KameleoonClient:
         """
         return "dataTracking?" + urlencode(self._get_common_ssx_parameters(visitor_code))
 
+    def _get_api_data_request_url(self, key: str) -> str:
+        """
+
+        :param key:
+        :return:
+        """
+        params = {
+            'siteCode': self.site_code,
+            'key': key
+        }
+        return self.api_data_url + "data?" + urlencode(params)
+
     def get_feature_flag(self, feature_key: Union[int, str]) -> Dict[str, Any]:
         """
 
